@@ -49,11 +49,15 @@
 typedef struct {
   const char	*name;
   tree_cell*	(*c_code)(lex_ctxt*);
-  int		unnamed;	/* Nb of unnamed args */
-  const char	*args[16];	/* Must be sorted! Finish list with NULL */
+  int		unnamed;	/**< Number of unnamed arguments. */
+  const char	*args[16];	/**< Must be sorted and terminated with NULL. */
 } init_func;
 
-
+/**
+ * Mapping of function names in NASL (eg. script_name("english")) to the
+ * C function pointers (e.g. script_name (lex_ctx**) ), argument count and
+ * argument Meta-information (names).
+ */
 static init_func libfuncs[] = {
   { "script_name",	script_name, 1,
      { "deutsch", "english", "francais", "portugues", NULL } },
@@ -113,7 +117,6 @@ static init_func libfuncs[] = {
   { "get_source_port",	nasl_get_source_port, 1, { NULL } }, /* DOC! */
   
   { "cgibin",		cgibin,		  0, { NULL } },
-  { "is_cgi_installed",	nasl_is_cgi_installed, 1, {"item", "port", NULL } },
   { "http_open_socket",	http_open_socket, 1, { NULL } },
   { "http_head",	http_head,	  0, {"data", "item", "port", NULL } },
   { "http_get",   	http_get,	  0, {"data", "item", "port", NULL } },
@@ -441,7 +444,8 @@ int init_nasl_library(lex_ctxt* lexic)
 char * nasl_version()
 {
   static char vers[sizeof(VERSION) + 1];
-  strncpy(vers, VERSION, sizeof(vers) - 1);
+  strncpy(vers, VERSION, sizeof(vers) - 1); /* Flawfinder: ignore
+                                               (\0-termination taken care of) */
   vers[sizeof(vers) - 1 ] = '\0';
   return vers;
 }
