@@ -30,16 +30,15 @@
 extern int naslparse( naslctxt * );
 
 /**
- * Parse a .nasl file.
+ * Reload a preparse (if suitable) or parse a .nasl file anew.
  * @return 0 on success, -1 on error
  */
 int
-nasl_load_or_parse(naslctxt* ctx, const char* name1, const char * basename, const char * cache_dir)
+nasl_reload_or_parse(naslctxt* ctx, const char* name)
 {
-  if (init_nasl_ctx(ctx, name1) < 0)
+  if (init_nasl_ctx(ctx, name) < 0)
     return -1;
 
-
   if (naslparse(ctx))
     {
       fprintf(stderr, "\nParse error at or near line %d\n", ctx->line_nb);
